"""RunDec public package API."""

from importlib.metadata import PackageNotFoundError, version

from ._api import (
    AlH2AlL,
    AlL2AlH,
    AlphasExact,
    AlphasLam,
    DecMqDownOS,
    DecMqUpOS,
    Decoupling,
    LamExpl,
    LamImpl,
    compiled_AlH2AlL,
    compiled_AlL2AlH,
    compiled_AlphasExact,
    compiled_AlphasLam,
    compiled_DecMqDownOS,
    compiled_DecMqUpOS,
    compiled_LamExpl,
    compiled_LamImpl,
    compiled_mH2mL,
    compiled_mL2mH,
    compiled_mMS2m1S,
    compiled_mMS2mMS,
    compiled_mMS2mOS,
    compiled_mOS2mMS,
    compiled_mOS2mSI,
    mH2mL,
    mL2mH,
    mMS2m1S,
    mMS2mMS,
    mMS2mOS,
    mOS2mMS,
    mOS2mSI,
)

__all__ = [
    "LamExpl",
    "LamImpl",
    "AlphasLam",
    "AlphasExact",
    "Decoupling",
    "AlL2AlH",
    "AlH2AlL",
    "mMS2mMS",
    "mMS2mOS",
    "mMS2m1S",
    "mOS2mMS",
    "mOS2mSI",
    "DecMqUpOS",
    "DecMqDownOS",
    "mL2mH",
    "mH2mL",
    "compiled_LamExpl",
    "compiled_LamImpl",
    "compiled_AlphasLam",
    "compiled_AlphasExact",
    "compiled_AlL2AlH",
    "compiled_AlH2AlL",
    "compiled_DecMqUpOS",
    "compiled_DecMqDownOS",
    "compiled_mL2mH",
    "compiled_mH2mL",
    "compiled_mMS2mMS",
    "compiled_mMS2mOS",
    "compiled_mMS2m1S",
    "compiled_mOS2mMS",
    "compiled_mOS2mSI",
]

try:
    __version__ = version("rundex")
except PackageNotFoundError:
    __version__ = "0+unknown"
